=== modified file 'include/my_attribute.h'
--- include/my_attribute.h	2008-06-25 05:29:13 +0000
+++ include/my_attribute.h	2008-07-06 18:04:11 +0000
@@ -22,18 +22,12 @@
 #define _my_attribute_h
 
 /*
-  Disable __attribute__() on gcc < 2.7, g++ < 3.4, and non-gcc compilers.
-  Some forms of __attribute__ are actually supported in earlier versions of
-  g++, but we just disable them all because we only use them to generate
-  compilation warnings.
+  Disable __attribute__ for non GNU compilers, since we're using them
+  only to either generate or suppress warnings.
 */
 #ifndef __attribute__
 # if !defined(__GNUC__)
 #  define __attribute__(A)
-# elif GCC_VERSION < 2008
-#  define __attribute__(A)
-# elif defined(__cplusplus) && GCC_VERSION < 3004
-#  define __attribute__(A)
 # endif
 #endif
 
@@ -46,18 +40,9 @@
 # define ATTRIBUTE_FORMAT(style, m, n) __attribute__((format(style, m, n)))
 #endif
 
-/*
-
-   __attribute__((format(...))) on a function pointer is not supported
-   until  gcc 3.1
-*/
+
+#endif
+
 #ifndef ATTRIBUTE_FORMAT_FPTR
-# if (GCC_VERSION >= 3001)
-#  define ATTRIBUTE_FORMAT_FPTR(style, m, n) ATTRIBUTE_FORMAT(style, m, n)
-# else
-#  define ATTRIBUTE_FORMAT_FPTR(style, m, n)
-# endif /* GNUC >= 3.1 */
-#endif
-
-
+# define ATTRIBUTE_FORMAT_FPTR(style, m, n) ATTRIBUTE_FORMAT(style, m, n)
 #endif

=== modified file 'include/my_getopt.h'
--- include/my_getopt.h	2008-06-25 05:29:13 +0000
+++ include/my_getopt.h	2008-07-06 18:04:11 +0000
@@ -36,6 +36,8 @@
 #define GET_ASK_ADDR	 128
 #define GET_TYPE_MASK	 127
 
+#include <my_sys.h>
+
 enum get_opt_arg_type { NO_ARG, OPT_ARG, REQUIRED_ARG };
 
 struct st_typelib;

=== modified file 'storage/myisam/Makefile.am'
--- storage/myisam/Makefile.am	2008-07-06 16:55:29 +0000
+++ storage/myisam/Makefile.am	2008-07-06 18:04:11 +0000
@@ -34,43 +34,49 @@
 EXTRA_DIST =		mi_test_all.sh mi_test_all.res plug.in
 pkgdata_DATA =		mi_test_all mi_test_all.res
 
-noinst_LIBRARIES =	libmyisam.a 
-#bin_PROGRAMS =		myisamchk myisamlog myisampack
-bin_PROGRAMS =
+noinst_LTLIBRARIES =	libmyisam.la libmyisamutil.la \
+			libmyisamha.la libmyisamnone.la
+bin_PROGRAMS =		myisamchk myisamlog myisampack
 myisamchk_DEPENDENCIES=	$(LIBRARIES)
-myisamchk_LDADD=	libmyisam.a \
+myisamchk_LDADD=	libmyisamutil.la \
+			libmyisamnone.la \
 			$(top_builddir)/mysys/libmysyslt.la \
 			$(d_dbug) \
 			$(top_builddir)/strings/libmystringslt.la -lz
 myisamlog_DEPENDENCIES=	$(LIBRARIES)
-myisamlog_LDADD=	libmyisam.a \
+myisamlog_LDADD=	libmyisamutil.la \
+			libmyisamnone.la \
 			$(top_builddir)/mysys/libmysyslt.la \
 			$(d_dbug) \
 			$(top_builddir)/strings/libmystringslt.la -lz
 myisampack_DEPENDENCIES=$(LIBRARIES)
-myisampack_LDADD=	libmyisam.a \
+myisampack_LDADD=	libmyisamutil.la \
+			libmyisamnone.la \
 			$(top_builddir)/mysys/libmysyslt.la \
 			$(d_dbug) \
 			$(top_builddir)/strings/libmystringslt.la -lz
-#noinst_PROGRAMS =	mi_test1 mi_test2 mi_test3
+noinst_PROGRAMS =	mi_test1 mi_test2 mi_test3
 noinst_HEADERS =	myisamdef.h \
 			ha_myisam.h
 mi_test1_DEPENDENCIES=	$(LIBRARIES)
-mi_test1_LDADD=		libmyisam.a \
+mi_test1_LDADD=		libmyisamutil.la \
+			libmyisamnone.la \
 			$(top_builddir)/mysys/libmysyslt.la \
 			$(d_dbug) \
 			$(top_builddir)/strings/libmystringslt.la -lz
 mi_test2_DEPENDENCIES=	$(LIBRARIES)
-mi_test2_LDADD=		libmyisam.a \
+mi_test2_LDADD=		libmyisamutil.la \
+			libmyisamnone.la \
 			$(top_builddir)/mysys/libmysyslt.la \
 			$(d_dbug) \
 			$(top_builddir)/strings/libmystringslt.la -lz
 mi_test3_DEPENDENCIES=	$(LIBRARIES)
-mi_test3_LDADD=		libmyisam.a \
+mi_test3_LDADD=		libmyisamutil.la \
+			libmyisamnone.la \
 			$(top_builddir)/mysys/libmysyslt.la \
 			$(d_dbug) \
 			$(top_builddir)/strings/libmystringslt.la -lz
-libmyisam_a_SOURCES =	mi_open.c mi_extra.c mi_info.c mi_rkey.c \
+libmyisamutil_la_SOURCES = mi_open.c mi_extra.c mi_info.c mi_rkey.c \
 			mi_rnext.c mi_rnext_same.c \
 			mi_search.c mi_page.c mi_key.c mi_locking.c \
 			mi_rrnd.c mi_scan.c mi_cache.c \
@@ -85,8 +91,12 @@
 			mi_changed.c mi_static.c mi_delete_all.c \
 			mi_delete_table.c mi_rename.c  mi_check.c \
 			mi_keycache.c mi_preload.c \
-			sort.c \
-			ha_myisam.cc
+			sort.c 
+libmyisamha_la_SOURCES = ha_myisam.cc
+libmyisamnone_la_SOURCES = mi_reportnone.c
+libmyisam_la_SOURCES = 
+libmyisam_la_LIBADD = libmyisamha.la libmyisamutil.la
+
 CLEANFILES =		test?.MY? FT?.MY? isam.log mi_test_all
 
 # Move to automake rules ?

=== added file 'storage/myisam/mi_reportnone.c'
--- storage/myisam/mi_reportnone.c	1970-01-01 00:00:00 +0000
+++ storage/myisam/mi_reportnone.c	2008-07-06 18:04:11 +0000
@@ -0,0 +1,23 @@
+/* Copyright (C) 2000-2006 MySQL AB
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+
+#include "myisamdef.h"
+
+void _mi_report_crashed(MI_INFO *file __attribute__((unused)),
+                        const char *message __attribute__((unused)),
+                        const char *sfile __attribute__((unused)),
+                        uint sline __attribute__((unused)))
+{
+}

=== modified file 'storage/myisam/mi_test1.c'
--- storage/myisam/mi_test1.c	2008-07-06 13:01:13 +0000
+++ storage/myisam/mi_test1.c	2008-07-06 18:04:11 +0000
@@ -680,4 +680,3 @@
   my_print_variables(my_long_options);
 }
 
-#include "mi_extrafunc.h"

=== modified file 'storage/myisam/mi_test2.c'
--- storage/myisam/mi_test2.c	2008-06-25 05:29:13 +0000
+++ storage/myisam/mi_test2.c	2008-07-06 18:04:11 +0000
@@ -1053,4 +1053,3 @@
   return;
 }
 
-#include "mi_extrafunc.h"

=== modified file 'storage/myisam/mi_test3.c'
--- storage/myisam/mi_test3.c	2008-06-25 05:29:13 +0000
+++ storage/myisam/mi_test3.c	2008-07-06 18:04:11 +0000
@@ -500,4 +500,3 @@
 
 #endif /* __NETWARE__ */
 
-#include "mi_extrafunc.h"

=== modified file 'storage/myisam/myisamchk.c'
--- storage/myisam/myisamchk.c	2008-07-02 14:48:53 +0000
+++ storage/myisam/myisamchk.c	2008-07-06 18:04:11 +0000
@@ -15,12 +15,14 @@
 
 /* Describe, check and repair of MyISAM tables */
 
-#include "fulltext.h"
+#include <my_global.h>
 
 #include <m_ctype.h>
 #include <stdarg.h>
 #include <my_getopt.h>
 #include <my_bit.h>
+#include <myisam.h>
+#include <m_string.h>
 #ifdef HAVE_SYS_VADVICE_H
 #include <sys/vadvise.h>
 #endif
@@ -29,10 +31,10 @@
 #endif
 SET_STACK_SIZE(9000)			/* Minimum stack size for program */
 
-#ifndef USE_RAID
 #define my_raid_create(A,B,C,D,E,F,G) my_create(A,B,C,G)
 #define my_raid_delete(A,B,C) my_delete(A,B)
-#endif
+
+#include "myisamdef.h"
 
 static uint decode_bits;
 static char **default_argv;
@@ -42,7 +44,6 @@
 static long opt_myisam_block_size;
 static long opt_key_cache_block_size;
 static const char *my_progname_short;
-static int stopwords_inited= 0;
 static MY_TMPDIR myisamchk_tmpdir;
 
 static const char *type_names[]=
@@ -133,7 +134,6 @@
   }
   free_defaults(default_argv);
   free_tmpdir(&myisamchk_tmpdir);
-  ft_free_stopwords();
   my_end(check_param.testflag & T_INFO ? MY_CHECK_ERROR | MY_GIVE_INFO : MY_CHECK_ERROR);
   exit(error);
 #ifndef _lint
@@ -319,16 +319,6 @@
     BUFFERS_WHEN_SORTING, 4L, 100L, 0L, 1L, 0},
   { "decode_bits", OPT_DECODE_BITS, "", (uchar**) &decode_bits,
     (uchar**) &decode_bits, 0, GET_UINT, REQUIRED_ARG, 9L, 4L, 17L, 0L, 1L, 0},
-  { "ft_min_word_len", OPT_FT_MIN_WORD_LEN, "", (uchar**) &ft_min_word_len,
-    (uchar**) &ft_min_word_len, 0, GET_ULONG, REQUIRED_ARG, 4, 1, HA_FT_MAXCHARLEN,
-    0, 1, 0},
-  { "ft_max_word_len", OPT_FT_MAX_WORD_LEN, "", (uchar**) &ft_max_word_len,
-    (uchar**) &ft_max_word_len, 0, GET_ULONG, REQUIRED_ARG, HA_FT_MAXCHARLEN, 10,
-    HA_FT_MAXCHARLEN, 0, 1, 0},
-  { "ft_stopword_file", OPT_FT_STOPWORD_FILE,
-    "Use stopwords from this file instead of built-in list.",
-    (uchar**) &ft_stopword_file, (uchar**) &ft_stopword_file, 0, GET_STR,
-    REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
   {"stats_method", OPT_STATS_METHOD,
    "Specifies how index statistics collection code should treat NULLs. "
    "Possible values of name are \"nulls_unequal\" (default behavior for 4.1/5.0), "
@@ -953,8 +943,6 @@
   }
   else
   {
-    if (!stopwords_inited++)
-      ft_init_stopwords();
 
     if (!(param->testflag & T_READONLY))
       lock_type = F_WRLCK;			/* table is changed */
@@ -1792,4 +1780,3 @@
   DBUG_VOID_RETURN;
 }
 
-#include "mi_extrafunc.h"

=== modified file 'storage/myisam/myisamlog.c'
--- storage/myisam/myisamlog.c	2008-06-25 05:29:13 +0000
+++ storage/myisam/myisamlog.c	2008-07-06 18:04:11 +0000
@@ -846,4 +846,3 @@
   return strcmp(file_info->name,name) ? 1 : 0;
 }
 
-#include "mi_extrafunc.h"

=== modified file 'storage/myisam/myisampack.c'
--- storage/myisam/myisampack.c	2008-07-01 08:15:04 +0000
+++ storage/myisam/myisampack.c	2008-07-06 18:04:11 +0000
@@ -3200,5 +3200,3 @@
           (**count1 > **count2) ? -1 : 0);
 }
 #endif
-
-#include "mi_extrafunc.h"

=== modified file 'storage/myisam/plug.in'
--- storage/myisam/plug.in	2008-06-25 05:29:13 +0000
+++ storage/myisam/plug.in	2008-07-06 18:04:11 +0000
@@ -1,7 +1,7 @@
 MYSQL_STORAGE_ENGINE(myisam,no, [MyISAM Storage Engine],
         [Traditional non-transactional MySQL tables])
 MYSQL_PLUGIN_DIRECTORY(myisam,  [storage/myisam])
-MYSQL_PLUGIN_STATIC(myisam,     [libmyisam.a])
+MYSQL_PLUGIN_STATIC(myisam,     [libmyisam.la])
 MYSQL_PLUGIN_MANDATORY(myisam)  dnl Default
 MYSQL_PLUGIN_DEPENDS_ON_MYSQL_INTERNALS(myisam, [ha_myisam.cc])
 

